<?php

namespace App\Controller;

use App\Entity\Category;
use App\Form\CategoryType;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;

class CategoryController extends AbstractController
{
    /**
     * @Route("/admin/categories", name="categories")
     */
    public function index(): Response
    {
        return $this->render('category/categories.html.twig', [
//            'controller_name' => 'CategoryController',
            'categories' => $this->getDoctrine()->getRepository(Category::class)->findAll()
        ]);
    }

    /**
     * @Route("/admin/categories/add", name="category-add")
     * @param Request $request
     * @return Response
     */
    public function add(Request $request): Response
    {
        $cat = new Category();
        $form = $this->createForm(CategoryType::class, $cat);
        $form->handleRequest($request);
        if ($form->isSubmitted() && $form->isValid()) {
            $cat = $form->getData();
            $manager = $this->getDoctrine()->getManager();
            $manager->persist($cat);
            $manager->flush();
            return $this->redirectToRoute('categories');
        }
        return $this->render('category/categories-form.html.twig', [
//            'controller_name' => 'CategoryController',
            'form' => $form->createView(),
            'title' => 'Add new category'
        ]);
    }

    /**
     * @Route("/admin/categories/edit/{id}", name="category-edit")
     * @param Request $request
     * @param int $id
     * @return Response
     */
    public function edit(Request $request, int $id): Response
    {
        $manager = $this->getDoctrine()->getManager();
        $cat = $manager->getRepository(Category::class)->find($id);
        if (!$cat) {
            throw $this->createNotFoundException("Category not found");
        }
        $form = $this->createForm(CategoryType::class, $cat);
        $form->handleRequest($request);
        if ($form->isSubmitted() && $form->isValid()) {
            $manager->flush();
            return $this->redirectToRoute('categories');
        }
        return $this->render('category/categories-form.html.twig', [
//            'controller_name' => 'CategoryController',
            'form' => $form->createView(),
            'title' => 'Edit '.$cat->getName()
        ]);
    }

    /**
     * @Route("/admin/categories/remove/{id}", name="category-remove")
     * @param int $id
     * @return Response
     */
    public function remove(int $id): Response
    {
        $manager = $this->getDoctrine()->getManager();
        $cat = $manager->getRepository(Category::class)->find($id);
        if (!$cat) {
            throw $this->createNotFoundException("Category not found");
        }
        $manager->remove($cat);
        $manager->flush();
        return $this->redirectToRoute('categories');
    }

    public function categorySummary(): Response
    {
        return $this->render('category/category_summary.html.twig', [
//            'controller_name' => 'CategoryController',
            'Categories' => $this->getDoctrine()->getRepository(Category::class)->getCategorySummary()
        ]);
    }
}
