<?php

namespace App\Controller;

use App\Entity\Comment;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;

class CommentController extends AbstractController
{
    /**
     * @Route("/admin/comments", name="comments")
     */
    public function index(): Response
    {
        return $this->render('comment/comments.html.twig', [
//            'controller_name' => 'CommentController',
            'comments' => $this->getDoctrine()->getRepository(Comment::class)->findAll()
        ]);
    }

    /**
     * @Route("/admin/comments/valid/{id}", name="comment-valid")
     * @param int $id
     * @return Response
     */
    public function valid(int $id): Response
    {
        $manager = $this->getDoctrine()->getManager();
        $comm = $manager->getRepository(Comment::class)->find($id);
        if (!$comm) {
            throw $this->createNotFoundException("Comment not found");
        }
        $comm->setValid(true);
        $manager->flush();
        return $this->redirectToRoute('comments');
    }

    /**
     * @Route("/admin/comments/remove/{id}", name="comment-remove")
     * @param int $id
     * @return Response
     */
    public function remove(int $id): Response
    {
        $manager = $this->getDoctrine()->getManager();
        $comm = $manager->getRepository(Comment::class)->find($id);
        if (!$comm) {
            throw $this->createNotFoundException("Comment not found");
        }
        $manager->remove($comm);
        $manager->flush();
        return $this->redirectToRoute('comments');
    }

    public function recentComment(): Response
    {
        return $this->render('comment/recent_comment.html.twig', [
//            'controller_name' => 'CommentController',
            'comments' => $this->getDoctrine()->getRepository(Comment::class)->findBy(array('valid' => true), array('createdAt' => 'DESC'), 5, 0)
        ]);
    }
}
